@@ -317,6 +317,11 @@ class MathTable:
             kern2 += glyph2_kern.topleft.getkern(height2)
         return min(kern1, kern2), shiftdn
 
+    def listvariants(self, glyphid: int, vert: bool = True) -> dict[int, int]:
+        if vert:
+            return self._variantsvert.listvariants(glyphid)
+        return self._variantshorz.listvariants(glyphid)
+
     def variant(self, glyphid: int, height: float, vert: bool = True) -> GlyphType:
         ''' Get a height variant for the glyph
 
@@ -418,7 +423,7 @@ class AssembledGlyph(SimpleGlyph):
         self._xadvance = max([g.advance() for g in glyphs])
         super().__init__(index, [], bbox, font)
 
-    def advance(self, nextchr=None) -> float:
+    def advance(self, nextchr=None) -> int:
         ''' X-advance '''
         if self.vert:
             return self._xadvance
@@ -503,7 +508,10 @@ class MathAssembly:
             num_extenders += 1
 
         # Decrease overlap since full extenders make it too tall
-        dy = (size - reqsize) / (len(testparts)-1)
+        try:
+            dy = (size - reqsize) / (len(testparts)-1)
+        except ZeroDivisionError:
+            dy = (size - reqsize)
 
         # Build transforms for compound glyph
         offsets = []
@@ -540,6 +548,15 @@ class MathVariants:
         self.font = font
         self.vert = vert
 
+    def listvariants(self, glyphid: int) -> dict[int, int]:
+        ''' List all size variants '''
+        covidx = self.coverage.covidx(glyphid)
+        if covidx is None:
+            return {}
+
+        construction = self.construction[covidx]
+        return construction.variants
+
     def getvariant(self, glyphid: int, size: float) -> GlyphType:
         ''' Get the proper size variant for the glyphid '''
         glf: GlyphType
@@ -585,6 +602,10 @@ class MathVariants:
         else:
             height = ymax-ymin
             if height > ymaxs[-1] - ymins[-1] and construction.assembly:
+                if self.vert:
+                    height = max(
+                        -2*(ymin+self.font.math.consts.axisHeight),
+                        2*(ymax-self.font.math.consts.axisHeight))
                 glf = construction.assembly.assemble(height, self.minoverlap)
             else:
                 glf = self.font.glyph_fromid(gids[-1])
